@@ -340,6 +340,9 @@ class AppSettings(object):
     def SAME_SITE_COOKIE_NONE(self):
         return self._setting('SAME_SITE_COOKIE_NONE', False, bool)
 
+    @property
+    def SIGNALS_DISABLED_COMMANDS(self):
+        return self._setting('SIGNALS_DISABLED_COMMANDS', ['loaddata', 'dpb_couchdb_loaddata'], list)
 
 # Ugly? Pennersr says Guido recommends this himself ...
 # http://mail.python.org/pipermail/python-ideas/2012-May/014969.html
