@@ -14,11 +14,9 @@ class Command(BaseCommand):
 
         for user in users:
             try:
-                user.apigw_consumer_id = None
-                user.save()
-
-                # delete all user devices
-                user.sso_app_profile.devices.all().delete()
+                profile = user.sso_app_profile
+                profile.apigw_consumer_id = None
+                profile.save()
 
                 updated_users += 1
                 self.stdout.write(self.style.SUCCESS('{}/{}'.format(updated_users, users_count)))
