@@ -11,7 +11,7 @@ logger = logging.getLogger('django_sso_app.core.apps.devices')
 
 
 def get_request_device(request):
-    device = getattr(request, 'device', None)
+    device = get_session_key(request, '__dssoa__device', None)
 
     if device is None:
         logger.debug('no previous device')
@@ -60,7 +60,7 @@ def get_request_device(request):
 
     assert device is not None
 
-    setattr(request, 'device', device)
+    set_session_key(request, '__dssoa__device', device)
     set_session_key(request, '__dssoa__device__fingerprint', device.fingerprint)
 
     return device
