@@ -1,9 +1,8 @@
 import logging
 
 from django.dispatch import receiver
-from django.db.models.signals import post_save, pre_save
+from django.db.models.signals import post_save
 
-#from ..models import EmailAddress
 from allauth.account.models import EmailAddress
 
 logger = logging.getLogger('django_sso_app.core.apps.emails.signals')
@@ -11,6 +10,9 @@ logger = logging.getLogger('django_sso_app.core.apps.emails.signals')
 
 @receiver(post_save, sender=EmailAddress)
 def email_addresses_updated(sender, instance, created, **kwargs):
+    """
+    Manage email model updates, only one primary/verified email per user
+    """
 
     if kwargs['raw']:
         # https://github.com/django/django/commit/18a2fb19074ce6789639b62710c279a711dabf97
