@@ -50,6 +50,7 @@ class ProfileSerializer(AbsoluteUrlSerializer):
 
     is_incomplete = serializers.SerializerMethodField(required=False)
     required_fields = serializers.SerializerMethodField(required=False)
+    completed_at = serializers.BooleanField(required=False)
 
     class Meta:
         model = Profile
@@ -63,7 +64,7 @@ class ProfileSerializer(AbsoluteUrlSerializer):
             'user',
             'groups',
             'meta',
-            'is_incomplete', 'required_fields') + app_settings.USER_FIELDS
+            'is_incomplete', 'required_fields', 'completed_at') + app_settings.USER_FIELDS
         fields = read_only_fields + app_settings.PROFILE_FIELDS
 
     def get_groups(self, instance):
