@@ -1,90 +1,50 @@
 import logging
 
 from django.dispatch import receiver
-from django.db.models.signals import post_save, pre_save
+from django.db.models.signals import post_save
 from django.contrib.auth import get_user_model
 from django.contrib.auth.signals import user_logged_in
-from django.utils.timezone import now
 
-from ..utils import get_or_create_user_profile
-from ..models import Profile
+from ..utils import get_or_create_user_profile, is_django_staff
 
 logger = logging.getLogger('django_sso_app.core.apps.profiles.signals')
 
 User = get_user_model()
 
 
-@receiver(pre_save, sender=Profile)
-def profile_pre_updated(sender, instance, **kwargs):
-    """
-    Profile model has been updated, updating rev
-    """
-    if kwargs['raw']:
-        # https://github.com/django/django/commit/18a2fb19074ce6789639b62710c279a711dabf97
-        return
-
-    profile = instance
-
-    # set profile completed_at if all required fields are set
-    if not profile.is_incomplete and profile.completed_at is None:
-        profile.completed_at = now()
-
-    if not profile._state.adding:
-        user = profile.user
-
-        if getattr(user, '__dssoa__apigateway_update', False):
-            logger.debug('Profile has been updted by api gateway, skipping rev update')
-        elif getattr(user, '__dssoa__creating', False):
-            logger.debug('Created, skipping rev update')
-        else:
-            logger.debug('Profile model has been updated, updating rev')
-            profile.update_rev(False)
-
-
-@receiver(post_save, sender=Profile)
-def profile_updated(sender, instance, created, **kwargs):
-    """
-    Profile model has been updated, updating rev
-    """
-    profile = instance
-
-    if kwargs['raw']:
-        # https://github.com/django/django/commit/18a2fb19074ce6789639b62710c279a711dabf97
-        setattr(profile.user, '__dssoa__loaddata', True)
-        return
-
-    if not created:  # if instance.pk:
-        logger.debug('Profile model has been updated, refreshing instance')
-        profile.refresh_from_db()
-
 # user
 
 @receiver(post_save, sender=User)
 def create_update_user_profile(sender, instance, created, **kwargs):
+    """
+    Creates new user profile if not already done.
+    """
+    user = instance
+
     if kwargs['raw']:
         # https://github.com/django/django/commit/18a2fb19074ce6789639b62710c279a711dabf97
         # setting property flag
-        setattr(instance, '__dssoa__loaddata', True)
+        setattr(user, '__dssoa__loaddata', True)
         return
 
-    user = instance
-
     if created:
         logger.debug('backend signals user created')
 
         setattr(instance, '__dssoa__creating', True)
 
-        profile = get_or_create_user_profile(user, Profile, commit=True)
+        profile = get_or_create_user_profile(user, commit=True)
 
         logger.debug('new profile created "{}"'.format(profile))
 
-        # refreshing user instance
+        # refreshing user instance property
         user.sso_app_profile = profile
 
     else:
         logger.debug('backend signals user updated')
-        profile = get_or_create_user_profile(user, Profile, commit=False)
-        update_rev = True
+        profile = get_or_create_user_profile(user, commit=False)
+
+        # rev should update only for non django staff users
+        update_rev = not is_django_staff(user)
 
         # replaced by '__user_loggin_in'
         # if user.previous_serialized_as_string == user.serialized_as_string:
@@ -97,7 +57,11 @@ def create_update_user_profile(sender, instance, created, **kwargs):
         elif user.password_has_been_hardened:
             logger.info('password_has_been_hardened')
             update_rev = False
+        elif is_django_staff(user):
+            logger.info('User is staff, skipping rev update')
+            update_rev = False
 
+        # align profile user fields
         if user.email_has_been_updated:
             # aligning sso_app_profile django_user_email
             profile.django_user_email = user.sso_app_new_email
@@ -112,15 +76,13 @@ def create_update_user_profile(sender, instance, created, **kwargs):
 
 
 @receiver(user_logged_in)
-def post_user_login(**kwargs):
+def create_profile_for_legacy_users(**kwargs):
     """
-    Post login profile creation safety
-    :param kwargs:
-    :return:
+    Post login profile creation for user models created before django_sso_app.
     """
     user = kwargs['user']
 
-    _profile = get_or_create_user_profile(user, Profile)
+    _profile = get_or_create_user_profile(user)
     # setattr(user, 'sso_app_profile', _profile)
 
     logger.debug('Profile, "{}" LOGGED IN!!!'.format(_profile))
