@@ -10,11 +10,9 @@ from django.contrib.auth import get_user_model
 from ... import app_settings
 from ..api_gateway.kong.functions import get_apigateway_sso_id
 from ..emails.models import EmailAddress
-from ..profiles.utils import update_profile, get_or_create_user_profile
-from ..profiles.models import Profile
+from ..profiles.utils import update_profile
 
 logger = logging.getLogger('django_sso_app.core.apps.users')
-User = get_user_model()
 
 
 def fetch_remote_user(sso_id, encoded_jwt=None):
@@ -143,6 +141,8 @@ def create_local_user_from_object(user_object, verified=False):
     sso_id = user_object.get('sso_id', None)
     sso_rev = user_object.get('sso_rev', 0)
 
+    User = get_user_model()
+
     if sso_id is not None:
         sso_id = smart_str(sso_id)
 
