@@ -58,8 +58,8 @@ class DjangoSsoAppAppBaseAuthenticationBackend(ModelBackend):
             if first_access:
                 logger.info('"{} first access, updating ...'.format(user))
 
-            # update local profile from SSO
-            setattr(user, '__dssoa__apigateway_update', True)
+            # local profile updated from django_sso_app instance, do not update sso_rev
+            setattr(user, '__dssoa__creating', True)
 
             remote_user = fetch_remote_user(sso_id=sso_id, encoded_jwt=encoded_jwt)
             user = update_local_user_from_remote_backend(remote_user=remote_user,
