@@ -22,7 +22,7 @@ class TokenError(BaseException):
     pass
 
 
-class ProfileIncompleteException(BaseException):
+class ProfileIncompleteException(ImmediateHttpResponse):
     pass
 
 
