@@ -1,13 +1,11 @@
 import logging
 
-from django import forms
 from django.forms import CharField, DateField, FloatField, HiddenInput
 
 from allauth.account.forms import (LoginForm as allauth_LoginForm,
                                    SignupForm as allauth_SignupForm)
 from allauth.account.adapter import get_adapter
 from allauth.account import app_settings as allauth_app_settings
-from allauth.utils import get_user_model
 
 from .apps.emails.models import EmailAddress
 from .apps.services.models import Service
@@ -73,20 +71,11 @@ class BaseSignupForm(allauth_SignupForm):
         return kwargs
 
     def save(self, request):
-
         new_user = super(BaseSignupForm, self).save(request)
 
-        # test_mode check
-        test_mode = request.GET.get('test_mode', None)
-
         adapter = get_adapter(request)
-
-        username = self.cleaned_data.get("username", None)
-        email = self.cleaned_data.get("email", None)
-        fingerprint = self.cleaned_data.get("fingerprint", None)
         referer = self.cleaned_data["referer"]
         groups = self.cleaned_data.get("groups", '')
-        user_model = get_user_model()
 
         try:
             if new_user is not None:
